@@ -12,9 +12,15 @@ function (e1, e2)
         merge(e1, e2, all = FALSE, retclass = NULL)
         NextMethod(.Generic)
     }
+    if(!missing(e2))
+      if(is.zoo(e2)) XTS <- e2
+
+    if(is.zoo(e1)) XTS <- e1
+
     if (is.null(attr(e, "index"))) 
-        e <- xts(as.matrix(e), index(e1), attr(e1, "frequency"))
-    else e <- xts(e,index(e1))
+        e <- xts(coredata(e), index(XTS), attr(XTS, "frequency"))
+    else e <- xts(coredata(e),index(e))
+
     e
 }
 
